@@ -7,7 +7,7 @@ web service and databases.
 
 The only difference between the City and Insights model classes is which
 fields in each record may be populated. See
-http://dev.maxmind.com/geoip/geoip2/web-services for more details.
+https://dev.maxmind.com/geoip/docs/web-services?lang=en for more details.
 
 """
 # pylint: disable=too-many-instance-attributes,too-few-public-methods
@@ -339,7 +339,6 @@ class SimpleModel(SimpleEquality, metaclass=ABCMeta):
     def network(self) -> Optional[Union[ipaddress.IPv4Network, ipaddress.IPv6Network]]:
         """The network for the record"""
         # This code is duplicated for performance reasons
-        # pylint: disable=duplicate-code
         network = self._network
         if isinstance(network, (ipaddress.IPv4Network, ipaddress.IPv6Network)):
             return network
