@@ -19,7 +19,7 @@ class Record(SimpleEquality, metaclass=ABCMeta):
     """All records are subclasses of the abstract class ``Record``."""
 
     def __repr__(self) -> str:
-        args = ", ".join("%s=%r" % x for x in self.__dict__.items())
+        args = ", ".join(f"{k}={v!r}" for k, v in self.__dict__.items())
         return f"{self.__module__}.{self.__class__.__name__}({args})"
 
 
@@ -644,9 +644,7 @@ class Traits(Record):
 
     .. attribute:: is_anonymous_proxy
 
-      This is true if the IP is an anonymous
-      proxy. See http://dev.maxmind.com/faq/geoip#anonproxy for further
-      details.
+      This is true if the IP is an anonymous proxy.
 
       :type: bool
 
@@ -864,11 +862,10 @@ class Traits(Record):
         self._network = network
         self._prefix_len = prefix_len
 
-    # This code is duplicated for performance reasons
-    # pylint: disable=duplicate-code
     @property
     def network(self) -> Optional[Union[ipaddress.IPv4Network, ipaddress.IPv6Network]]:
         """The network for the record"""
+        # This code is duplicated for performance reasons
         network = self._network
         if isinstance(network, (ipaddress.IPv4Network, ipaddress.IPv6Network)):
             return network
